in help_line_len(), make the text display more flexible, and closer to
what nano 1.2.x does


git-svn-id: svn://svn.savannah.gnu.org/nano/trunk/nano@2418 35c25a1d-7b9e-4130-9fde-d3aeb78583b8
diff --git a/src/winio.c b/src/winio.c
index e2d7b80..9fd1188 100644
--- a/src/winio.c
+++ b/src/winio.c
@@ -3828,10 +3828,10 @@
 /* Calculate the next line of help_text, starting at ptr. */
 size_t help_line_len(const char *ptr)
 {
-    int help_cols = (COLS > 80) ? COLS - 8 : 72;
+    int help_cols = (COLS > 24) ? COLS - 8 : 24;
 
     /* Try to break the line at (COLS - 8) columns if we have more than
      * 80 columns, and at 72 columns otherwise. */
     size_t retval = break_line(ptr, help_cols, TRUE);
     size_t retval_save = retval;
@@ -3828,10 +3828,10 @@
 
     /* Try to break the line at (COLS - 8) columns if we have more than
-     * 80 columns, and at 72 columns otherwise. */
+     * 24 columns, and at 24 columns otherwise. */
     size_t retval = break_line(ptr, help_cols, TRUE);
     size_t retval_save = retval;